import os
import logging


class VariablesConfig(object):

    missing_env_vars = list()
    logger = logging.getLogger("VariablesConfig")

    def __init__(self, required_env_vars, optional_env_vars=None):

        for env_var in required_env_vars:
            value = os.getenv(env_var)
            if not value:
                self.missing_env_vars.append(env_var)
            setattr(self, env_var, value)

        if optional_env_vars:
            for env_var in optional_env_vars:
                value = os.getenv(env_var)
                if not value:
                    value = None
                setattr(self, env_var, value)

    def validate(self):
        if len(self.missing_env_vars) != 0:
            self.logger.error(f"Missing the following required environment variable(s) {self.missing_env_vars}")
            return False
        return True



import os

from setuptools import setup, find_packages


here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, 'README.md')) as f:
    README = f.read()

with open(os.path.join(here, "python", 'VERSION.txt')) as f:
    VERSION = f.read().strip()

setup(
    name='sesamutils',
    version=VERSION,
    description='Sesam microservice utils',
    long_description=README,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP",
    ],
    author='Anders Borud',
    url='https://github.com/sesam-community/',
    packages=find_packages()
)
